@@ -404,7 +404,7 @@ def interceptor_db_con(fn, db_info, *args, **kwargs):
             x.split('=') for x in re.sub(r'\s*=\s*', '=', args[0]).split())
 
     text = '{}://'.format(db_info.get('type'))
-    text += kwargs.get('user')
+    text += kwargs.get('user' , '')
     text += "@"
     text += kwargs.get('host', kwargs.get('dsn', ''))
     text += '/'
@@ -421,7 +421,7 @@ def interceptor_db_con(fn, db_info, *args, **kwargs):
     return callback
 
 
-def addQuoteList(arg_dict):
+def addQuoteDict(arg_dict):
     quoted_dict = dict()
 
     for k, v in arg_dict.items():
@@ -452,7 +452,7 @@ def interceptor_db_execute(fn, db_info, *args, **kwargs):
     query = None
     if len(args) > 2 and type(args[2]) == dict and args[2]:
         try:
-            query = args[1] % addQuoteList(args[2])
+            query = args[1] % addQuoteDict(args[2])
         except Exception as e:
             pass
     if len(args) > 2 and type(args[2]) in (list, tuple) and args[2]:
@@ -473,7 +473,7 @@ def interceptor_db_execute(fn, db_info, *args, **kwargs):
     ctx.start_time = start_time
 
     text = '{}://'.format(db_info.get('type'))
-    text += db_info.get('user')
+    text += db_info.get('user' , '')
     text += "@"
     text += db_info.get('host', db_info.get('dsn', ''))
     text += '/'
@@ -500,7 +500,8 @@ def interceptor_db_execute(fn, db_info, *args, **kwargs):
         ctx.elapsed = DateUtil.nowSystem() - start_time
         async_sender.send_packet(PacketTypeEnum.TX_SQL, ctx, datas)
         count = self.rowcount
-        if count > -1:
+
+        if (count is not None) and (count > -1):
             desc = '{0}: {1}'.format('Fetch count', count)
             datas = [' ', ' ', desc]
             ctx.elapsed = 0
