@@ -70,7 +70,7 @@ class WhatapMongoCmdEventListener(pymongo.monitoring.CommandListener):
             query +=' query: {}'.format(ctx.active_sqlhash)
 
         ctx.db_opening = False
-        datas = [ctx.lctx.get('dbc', ''), query]
+        datas = [ctx.lctx.get('dbc', ''), query, 0]
         ctx.elapsed = int(event.duration_micros / 1000)
         async_sender.send_packet(PacketTypeEnum.TX_SQL, ctx,
                                datas)
