@@ -9,7 +9,8 @@ def instrument_psycopg2(module):
         @trace_handler(fn)
         def trace(*args, **kwargs):
             global db_info
-            db_info = {'type': 'postgresql'} | kwargs
+            db_info = {'type': 'postgresql'}
+            db_info.update(kwargs)
             callback = interceptor_db_con(fn, db_info, *args, **kwargs)
             return callback
 
