@@ -78,7 +78,14 @@ def instrument_sqlalchemy_engine(module):
             except Exception as e:
                 query = str(args[2])
             # print('instrument_sqlalchemy_engine 3:', query)
-            if not query :
+            sqlalchemy_track_skip = False
+            except_track_module = ['pymysql', 'mysqldb', 'psycopg2']
+
+            # 이미 DB드라이브 추적 모듈이 존재하면 sqlAlhechmy 의 추적 중지
+            if any(keyword in str(args[0]) for keyword in except_track_module):
+                sqlalchemy_track_skip = True
+
+            if (not query) or (sqlalchemy_track_skip):
                 return fn(*args, **kwargs)
 
             start_time = DateUtil.nowSystem()
